# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1] - 2025-04-18

### Fixed
- Fixed inconsistency in help message for default port (now correctly shows 8000 instead of 3001)

## [0.1.0] - 2025-04-18

### Added
- Initial release of the mcp-think package
- Implemented the `think` tool for LLMs to use for structured thinking
- Support for both stdio and SSE transports
- Basic documentation and examples